@@ -34,7 +34,7 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
         Returns:
             dict: global configuration object
         """
-        self.util = Util(path=config["docs_dir"], config=self.config)
+        self.util = Util(config=self.config)
 
         # Get locale settings - might be added in future mkdocs versions
         # see: https://github.com/timvink/mkdocs-git-revision-date-localized-plugin/issues/24
@@ -89,58 +89,6 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
 
         return config
 
-    def on_post_page(self, output_content: str, **kwargs) -> str:
-        """
-        Add timeago.js as a CDN to the HTML page.
-        The CDN with latest version timeago.js can be found on
-        https://cdnjs.com/libraries/timeago.js
-
-        The `post_template` event is called after the template is rendered,
-        but before it is written to disc and can be used to alter the output
-        of the page. If an empty string is returned, the page is skipped
-        and nothing is written to disc.
-
-        https://www.mkdocs.org/user-guide/plugins/#on_post_page
-
-        Args:
-            output_content (str): output of rendered template as string
-
-        Returns:
-            str: output of rendered template as string
-        """
-
-        if self.config.get("type") != "timeago":
-            return output_content
-
-        # Insert timeago.js dependencies
-        extra_js = """
-          <script src="https://cdnjs.cloudflare.com/ajax/libs/timeago.js/4.0.0-beta.2/timeago.min.js"></script>
-          <script src="https://cdnjs.cloudflare.com/ajax/libs/timeago.js/4.0.0-beta.2/timeago.locales.min.js"></script>
-          <script>
-            var nodes = document.querySelectorAll('.timeago');
-            var locale = nodes[0].getAttribute('locale');
-            timeago.render(nodes, locale);
-          </script>
-        """
-        idx = output_content.index("</body>")
-        output_content = output_content[:idx] + extra_js + output_content[idx:]
-
-        # timeago output is dynamic, which breaks when you print a page
-        # This ensures fallback to type "iso_date"
-        extra_css = """
-        <style>
-        .git-revision-date-localized-plugin-iso_date { display: none }
-        @media print {
-           .git-revision-date-localized-plugin-iso_date { display: inline } 
-           .git-revision-date-localized-plugin-timeago { display: none } 
-        }
-        </style>
-        """
-        idx = output_content.index("</head>")
-        output_content = output_content[:idx] + extra_css + output_content[idx:]
-
-        return output_content
-
     def on_page_markdown(
         self, markdown: str, page: Page, config: config_options.Config, files, **kwargs
     ) -> str:
@@ -185,3 +133,66 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
             markdown,
             flags=re.IGNORECASE,
         )
+
+    def on_post_page(self, output_content: str, **kwargs) -> str:
+        """
+        Add timeago.js as a CDN to the HTML page.
+        The CDN with latest version timeago.js can be found on
+        https://cdnjs.com/libraries/timeago.js
+
+        The `post_template` event is called after the template is rendered,
+        but before it is written to disc and can be used to alter the output
+        of the page. If an empty string is returned, the page is skipped
+        and nothing is written to disc.
+
+        https://www.mkdocs.org/user-guide/plugins/#on_post_page
+
+        Args:
+            output_content (str): output of rendered template as string
+
+        Returns:
+            str: output of rendered template as string
+        """
+
+        if self.config.get("type") != "timeago":
+            return output_content
+
+        # Insert timeago.js dependencies
+        extra_js = """
+          <script src="https://cdnjs.cloudflare.com/ajax/libs/timeago.js/4.0.0-beta.2/timeago.min.js"></script>
+          <script src="https://cdnjs.cloudflare.com/ajax/libs/timeago.js/4.0.0-beta.2/timeago.locales.min.js"></script>
+          <script>
+          if (
+            typeof app !== "undefined" && 
+            typeof app.document$ !== "undefined"
+            ) {
+            app.document$.subscribe(function() {
+                var nodes = document.querySelectorAll('.timeago');
+                var locale = nodes[0].getAttribute('locale');
+                timeago.render(nodes, locale);
+            })
+         } else {
+             var nodes = document.querySelectorAll('.timeago');
+             var locale = nodes[0].getAttribute('locale');
+             timeago.render(nodes, locale);
+         }
+          </script>
+        """
+        idx = output_content.index("</body>")
+        output_content = output_content[:idx] + extra_js + output_content[idx:]
+
+        # timeago output is dynamic, which breaks when you print a page
+        # This ensures fallback to type "iso_date"
+        extra_css = """
+        <style>
+        .git-revision-date-localized-plugin-iso_date { display: none }
+        @media print {
+           .git-revision-date-localized-plugin-iso_date { display: inline } 
+           .git-revision-date-localized-plugin-timeago { display: none } 
+        }
+        </style>
+        """
+        idx = output_content.index("</head>")
+        output_content = output_content[:idx] + extra_css + output_content[idx:]
+
+        return output_content
